<?php
class IDF_wizard {
	function __construct() {
		add_filter( 'plugin_action_links_ignitiondeck/idf.php', array($this, 'idf_settings_link' ) );
		add_filter( 'plugin_row_meta', array( $this, 'idf_plugin_row_meta' ), 10, 2 );
		
		add_action('wp_ajax_idf_wizard_register', array($this, 'register'));
		add_action('wp_ajax_idf_wizard_install_plugins', array($this, 'install_plugins'));
		add_action('wp_ajax_idf_wizard_activate_plugins', array($this, 'activate_plugins'));
		add_action('wp_ajax_idf_wizard_verify_license', array($this, 'verify_license'));
		add_action('wp_ajax_idf_wizard_save_payment', array($this, 'save_payment'));
		add_action('wp_ajax_idf_wizard_install_themes', array($this, 'install_themes'));
	}

	function idf_settings_link( $links ) {
		$url = esc_url( add_query_arg(
			'page',
			'idf',
			get_admin_url() . 'admin.php?page=idf#wiz-register'
		) );
		$settings_link = "<a href='$url'>" . __( 'Settings' ) . '</a>';
		array_unshift(
			$links,
			$settings_link
		);
		return $links;
	}

	function idf_plugin_row_meta( $links, $file ) {
		if ( 'ignitiondeck/idf.php' !== $file ) {
			return $links;
		}
		$docs_url = 'https://docs.ignitiondeck.com/';
		$getting_started_url = 'https://docs.ignitiondeck.com/category/15-getting-started';
		$edition_url = 'https://docs.ignitiondeck.com/article/47-which-plugin-package-is-right-for-me';
		$valet_url = 'https://docs.ignitiondeck.com/article/154-how-to-request-the-valet-setup-service';

		$row_meta = array(
			'docs'    => '<a href="' . esc_url( $docs_url ) . '" aria-label="' . esc_attr__( 'View IgnitionDeck documentation', 'idf' ) . '">' . esc_html__( 'Documentation Site', 'idf' ) . '</a>',
			'getting_started' => '<a href="' . esc_url( $getting_started_url ) . '" aria-label="' . esc_attr__( 'View Getting Started', 'idf' ) . '">' . esc_html__( 'Getting Started', 'idf' ) . '</a>',
			'support' => '<a href="' . esc_url( $edition_url ) . '" aria-label="' . esc_attr__( 'Which Edition Is Right For Me?', 'idf' ) . '">' . esc_html__( 'Which Edition Is Right For Me?', 'idf' ) . '</a>',
			'valet' => '<a href="' . esc_url( $valet_url ) . '" aria-label="' . esc_attr__( 'Valet Service', 'idf' ) . '">' . esc_html__( 'Valet Service', 'idf' ) . '</a>',
		);

		return array_merge( $links, $row_meta );
	}

	function register() {
		$list_id = '500a881df9';
		$api_key = 'd7f27ffef3153597c80be0caf09686c5-us20';

		$email = $_POST['email'];
		update_option('idf_registered_email',$email);

		$params = array (
			'email_address'	=> $email,
			'status'		=> 'subscribed',
			'tags'  => array('Dashboard'),
		);

		$curl = curl_init();

		curl_setopt_array($curl, array(
		CURLOPT_URL => 'https://us20.api.mailchimp.com/3.0/lists/'.$list_id.'/members',
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_ENCODING => '',
		CURLOPT_MAXREDIRS => 10,
		CURLOPT_TIMEOUT => 0,
		CURLOPT_SSL_VERIFYPEER => 0,
		CURLOPT_FOLLOWLOCATION => true,
		CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
		CURLOPT_CUSTOMREQUEST => 'POST',
		CURLOPT_POSTFIELDS => json_encode($params),
		CURLOPT_HTTPHEADER => array(
				'Authorization: apikey '.$api_key,
				'Content-Type: application/json',
			),
		));

		$response = curl_exec($curl);
		if (curl_errno($curl)) {
			$error_msg = curl_error($curl);
		}
		curl_close($curl);

		if(isset($error_msg))
			echo json_encode(['error'=>true,'message'=>$error_msg]);
		else
			echo $response;
		
		exit;
	}

	function install_plugins() {

		$plugin = array(
			'name'	=>	$_POST['name'],
			'slug'	=>	$_POST['slug'],
			'url'	=>	$_POST['url'],
		);

		$status = 'Not Installed';
		if ( $this->is_plugin_installed( $plugin['slug'] ) ) {
			$this->upgrade_plugin( $plugin['slug'] );
			$installed = true;
			$status = 'Updated';
		} else {
			$installed = $this->install_plugin( $plugin['url'] );
			$status = 'Not Active';
		}
			
		echo $status;
		exit;
	}
	
	function activate_plugins() {

		$plugin = array(
			'name'	=>	$_POST['name'],
			'slug'	=>	$_POST['slug'],
			'url'	=>	$_POST['url'],
		);

		$status = 'Not Active';
			
		$activate = activate_plugin( $plugin['slug'] );
		$status = 'Installed and Activated';
		echo $status;
		exit;
	}

	function install_plugin( $plugin_zip ) {
		include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		wp_cache_flush();
		$upgrader = new Plugin_Upgrader();
		$installed = $upgrader->install( $plugin_zip );
		return $installed;
	}	
		
	function upgrade_plugin( $plugin_slug ) {
		include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		wp_cache_flush();
		$upgrader = new Plugin_Upgrader();
		$upgraded = $upgrader->upgrade( $plugin_slug );
		return $upgraded;
	}

	function is_plugin_installed( $slug ) {
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$all_plugins = get_plugins();
		if ( !empty( $all_plugins[$slug] ) ) {
			return true;
		} else {
			return false;
		}
	}

	function verify_license() {
		$key = sanitize_text_field($_POST['license']);
		idcf_license_update($key);
		require_once WP_PLUGIN_DIR . '/ignitiondeck/templates/admin/_idfMenu/upgrade.php';
		require_once WP_PLUGIN_DIR . '/ignitiondeck/templates/admin/_idfMenu/configure.php';
		exit;
	}

	function save_payment() {
		$save_payment = sanitize_text_field($_POST['payment']);
		update_option('idf_commerce_platform',$save_payment);
		do_action('idf_update_commerce_platform', $save_payment);
		require_once WP_PLUGIN_DIR . '/ignitiondeck/templates/admin/_idfMenu/upgrade.php';
		require_once WP_PLUGIN_DIR . '/ignitiondeck/templates/admin/_idfMenu/configure.php';
		exit;
	}

	function install_themes() {
		$status = __( 'Installed' );
		$theme = array(
			'url'	=>	$_POST['url'],
			'slug'	=>	$_POST['slug'],
		);

		$all_themes = wp_get_themes();
		if(empty( $all_themes[$theme['slug']] )) {
			require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
			include_once ABSPATH . 'wp-admin/includes/theme.php';

			$skin     = new WP_Ajax_Upgrader_Skin();
			$upgrader = new Theme_Upgrader( $skin );
			$result   = $upgrader->install( $theme['url'] );
			if ( is_wp_error( $result ) ) {
				$status = $result->get_error_message();
			} elseif ( is_wp_error( $skin->result ) ) {
				$status = $skin->result->get_error_message();
			} elseif ( $skin->get_errors()->has_errors() ) {
				$status = $skin->get_error_messages();
			} elseif ( is_null( $result ) ) {
				global $wp_filesystem;
		
				$status = __( 'Unable to connect to the filesystem. Please confirm your credentials.' );
		
				// Pass through the error from WP_Filesystem if one was raised.
				if ( $wp_filesystem instanceof WP_Filesystem_Base && is_wp_error( $wp_filesystem->errors ) && $wp_filesystem->errors->has_errors() ) {
					$status = esc_html( $wp_filesystem->errors->get_error_message() );
				}
			}
		}
		//switch_theme($theme['slug'], $theme['slug']);

		echo $status;
		exit;
	}
}
new IDF_wizard();
?>